@@ -10,7 +10,7 @@ from dateutil.tz import tzoffset, tzlocal
 import http.client
 from http.cookies import SimpleCookie
 from cgi import FieldStorage
-from omnitools import dt2yyyymmddhhmmss, HeadersDict, ApacheHeadersDict, str2html, encodeURIComponent
+from omnitools import dt2yyyymmddhhmmss, HeadersDict, ApacheHeadersDict, str2html, encodeURIComponent, dt2rfc822gmt, rfc822gmt2dt
 
 
 _SERVER = dict(os.environ)
@@ -167,20 +167,18 @@ def _should_return_304(fp: str = None):
     if not fp or not os.path.isfile(fp):
         return False
     lastmodified = math.floor(os.path.getmtime(fp))
-    lastmodified = datetime.datetime.fromtimestamp(lastmodified, tz=tzoffset(None, 0))
-    set_header("Last-Modified", lastmodified.strftime("%a, %d %b %Y %H:%M:%S GMT"))
+    lastmodified = datetime.datetime.fromtimestamp(lastmodified)
+    set_header("Last-Modified", dt2rfc822gmt(lastmodified))
     if "If-Modified-Since" in _HEADERS:
-        ims = email.utils.parsedate(_HEADERS["If-Modified-Since"])[:6]
-        if ims:
-            ims = datetime.datetime(*ims, tzinfo=tzoffset(None, 0))
-            if ims >= lastmodified:
-                return True
+        ims = rfc822gmt2dt(_HEADERS["If-Modified-Since"])
+        if ims and ims >= lastmodified:
+            return True
     return False
 
 
-def should_return_304(*args, **kwargs):
+def should_return_304(fp: str):
     def _304():
-        return _should_return_304(*args, **kwargs)
+        return _should_return_304(fp)
 
     return _304
 
@@ -267,7 +265,7 @@ def print_file(fo, buf_size: int = 32 * 1024, range = None):
         buf = None
         if not buffer:
             break
-        print(buffer)
+        print(buffer, end="")
         buffer = None
         flush()
     fo.close()
@@ -276,7 +274,7 @@ def print_file(fo, buf_size: int = 32 * 1024, range = None):
 def execute(
         method: str = "get", cacheable: bool = False,
         cache_ctrl = _cache_control,
-        cache_norm = should_return_304(),
+        cache_norm = _should_return_304,
         cache_strat = _should_read_from_cache_file,
         cache_store = _write_to_cache_file,
         enable_tb: bool = True, traceback_kwargs: dict = None
@@ -304,7 +302,6 @@ def execute(
                         cache_store(__response)
             except:
                 log(_traceback.format_exc(limit, chain))
-                __response.pop("cache")
                 __response["headers"].update(default_content_type)
                 if enable_tb:
                     tb = traceback(**(traceback_kwargs or {}))
